@@ -9,6 +9,7 @@ __email__ = "arenas.guerrero.julian@outlook.com"
 import json
 import pandas as pd
 
+from lxml import etree
 from jsonpath import JSONPath
 
 from ..constants import *
@@ -19,17 +20,17 @@ def get_file_data(config, mapping_rule, references):
 
     if file_source_type in [CSV, TSV]:
         return _read_csv(config, mapping_rule, references, file_source_type)
-    elif file_source_type == EXCEL:
+    elif file_source_type in EXCEL:
         return _read_excel(config, mapping_rule, references)
     elif file_source_type == PARQUET:
         return _read_parquet(mapping_rule, references)
-    elif file_source_type == FEATHER:
+    elif file_source_type in FEATHER:
         return _read_feather(mapping_rule, references)
     elif file_source_type == ORC:
         return _read_orc(mapping_rule, references)
     elif file_source_type == STATA:
         return _read_stata(config, mapping_rule, references)
-    elif file_source_type == SAS:
+    elif file_source_type in SAS:
         return _read_sas(config, mapping_rule, references)
     elif file_source_type == SPSS:
         return _read_spss(mapping_rule, references)
@@ -53,10 +54,9 @@ def _read_csv(config, mapping_rule, references, file_source_type):
                          chunksize=config.get_chunksize(),
                          engine='c',
                          dtype=str,
-                         memory_map=False,
                          keep_default_na=False,
                          na_values=config.get_na_values(),
-                         na_filter=config.apply_na_filter())
+                         na_filter=False)
 
 
 def _read_parquet(mapping_rule, references):
@@ -119,28 +119,42 @@ def _read_excel(config, mapping_rule, references):
                              dtype=str,
                              keep_default_na=False,
                              na_values=config.get_na_values(),
-                             na_filter=config.apply_na_filter())
+                             na_filter=False)
 
     return [excel_df]
 
 
 def _read_json(mapping_rule, references):
-    with open(str(mapping_rule['data_source']), encoding='utf-8') as jsonfile:
-        json_data = json.load(jsonfile)
+    with open(str(mapping_rule['data_source']), encoding='utf-8') as json_file:
+        json_data = json.load(json_file)
 
-    jsonpath_result = JSONPath(mapping_rule['iterator']).parse(json_data)
+    jsonpath_expression = mapping_rule['iterator'] + '.('
+    for reference in references:
+        jsonpath_expression += reference + ','
+    jsonpath_expression = jsonpath_expression[:-1] + ')'
+
+    jsonpath_result = JSONPath(jsonpath_expression).parse(json_data)
     json_df = pd.DataFrame.from_records(jsonpath_result)
-    json_df = json_df[references]
+    json_df.dropna(axis=0, how='any', inplace=True)
+
+    # in case lists where retrieved, explode them e.g.: ['a', 'b'] -> 'a', 'b'
+    for reference in references:
+        json_df = json_df.explode(reference)
 
     return [json_df]
 
 
 def _read_xml(mapping_rule, references):
-    xml_df = pd.read_xml(mapping_rule['data_source'],
-                         xpath=mapping_rule['iterator'],
-                         parser='lxml',
-                         encoding='utf-8')
+    with open(str(mapping_rule['data_source']), encoding='utf-8') as xml_file:
+        xml_root = etree.parse(xml_file).getroot()
 
-    xml_df = xml_df[references]
+    xpath_expression = mapping_rule['iterator']
+    for reference in references:
+        xpath_expression += '[' + reference + ']'
+
+    xpath_result = xml_root.xpath(xpath_expression)
+    xpath_result = [[e.find(reference).text for reference in references] for e in xpath_result]
+
+    xml_df = pd.DataFrame.from_records(xpath_result, columns=references)
 
     return [xml_df]
