@@ -292,7 +292,7 @@ class MappingParser:
 
     def parse_mappings(self):
         self._get_from_r2_rml()
-        self._normalize_mappings()
+        self._preprocess_mappings()
         self._infer_datatypes()
 
         self.validate_mappings()
@@ -368,11 +368,14 @@ class MappingParser:
         # convert the SPARQL result set with the parsed mappings to DataFrame
         return _transform_mappings_into_dataframe(mapping_query_results, join_query_results, section_name)
 
-    def _normalize_mappings(self):
+    def _preprocess_mappings(self):
         # start by removing duplicated triples
         self.mappings_df = self.mappings_df.drop_duplicates()
 
-        # complete source type with reference formulation
+        # complete rml:source with file_paths specified in the config file
+        self._complete_rml_source_with_config_file_paths()
+
+        # complete source type with config parameters and data file extensions
         self._complete_source_types()
 
         # ignore the delimited identifiers (this is not conformant with R2MRL specification)
@@ -391,22 +394,29 @@ class MappingParser:
 
     def _complete_source_types(self):
         """
-        Adds a column with the source type. The source type is taken from the value provided in the config for that data
-        source. If it is not provided, it is taken from the reference formulation in the mapping rule.
+        Adds a column with the source type. The source type is inferred for RDB through the parameter db_url provided
+        in the mapping file. For data files the source type is inferred from the file extension.
         """
 
         for i, mapping_rule in self.mappings_df.iterrows():
-            if self.config.has_source_type(mapping_rule['source_name']):
-                # take the source type from the config if it is provided
-                self.mappings_df.at[i, 'source_type'] = self.config.get_source_type(mapping_rule['source_name']).upper()
-            elif pd.notna(mapping_rule['ref_form']):
-                # take the source type from the reference formulation (fragment) in the mapping rules
-                self.mappings_df.at[i, 'source_type'] = str(mapping_rule['ref_form']).split('#')[-1].upper()
+            if self.config.has_database_url(mapping_rule['source_name']):
+                self.mappings_df.at[i, 'source_type'] = RDB
+            elif pd.notna(mapping_rule['data_source']):
+                file_extension = os.path.splitext(str(mapping_rule['data_source']))[1][1:].strip()
+                self.mappings_df.at[i, 'source_type'] = file_extension.upper()
             else:
-                logging.error('No source type could be retrieved for mapping rule some mapping rules.')
+                raise Exception('No source type could be retrieved for mapping rule some mapping rules.')
 
-        # ref form is no longer needed, remove it
-        self.mappings_df = self.mappings_df.drop('ref_form', axis=1)
+    def _complete_rml_source_with_config_file_paths(self):
+        """
+        Overrides rml:source in the mappings with the file_path parameter in the config file for each data source
+        section if provided.
+        """
+
+        for section_name in self.config.get_data_sources_sections():
+            if self.config.has_file_path(section_name):
+                self.mappings_df.loc[self.mappings_df['source_name'] == section_name, 'data_source'] = \
+                    self.config.get_file_path(section_name)
 
     def _remove_delimiters_from_mappings(self):
         """
@@ -551,6 +561,16 @@ class MappingParser:
             logging.warning('Found object maps with a language tag and a datatype. Both of them cannot be used '
                             'simultaneously for the same object map, and the language tag has preference.')
 
+        # check that language tags are valid
+        language_tags = set(self.mappings_df['object_language'].dropna())
+        # the place to look for valid language subtags is the IANA Language Subtag Registry
+        # (https://www.iana.org/assignments/language-subtag-registry/language-subtag-registry)
+        for language_tag in language_tags:
+            # in general, if the language subtag is longer than 3 characters it is not valid
+            if len(language_tag.split('-')[0]) > 3:
+                raise ValueError('Found invalid language tag `' + language_tag +
+                                 '`. Language tags must be in the IANA Language Subtag Registry.')
+
         # check that a triples map id is not repeated in different data sources
         # Get unique source names and triples map identifiers
         aux_mappings_df = self.mappings_df[['source_name', 'triples_map_id']].drop_duplicates()
